@@ -87,16 +87,21 @@ class MSOfficeParser(ZipParser):
         self.files_to_keep = set(map(re.compile, {  # type: ignore
             r'^\[Content_Types\]\.xml$',
             r'^_rels/\.rels$',
-            r'^(?:word|ppt)/_rels/document\.xml\.rels$',
-            r'^(?:word|ppt)/_rels/footer[0-9]*\.xml\.rels$',
-            r'^(?:word|ppt)/_rels/header[0-9]*\.xml\.rels$',
+            r'^(?:word|ppt|xl)/_rels/document\.xml\.rels$',
+            r'^(?:word|ppt|xl)/_rels/footer[0-9]*\.xml\.rels$',
+            r'^(?:word|ppt|xl)/_rels/header[0-9]*\.xml\.rels$',
+            r'^(?:word|ppt|xl)/styles\.xml$',
+            # TODO: randomize axId ( https://docs.microsoft.com/en-us/openspecs/office_standards/ms-oi29500/089f849f-fcd6-4fa0-a281-35aa6a432a16 )
+            r'^(?:word|ppt|xl)/charts/chart[0-9]*\.xml$',
+            r'^xl/workbook\.xml$',
+            r'^xl/worksheets/sheet[0-9]+\.xml$',
             r'^ppt/slideLayouts/_rels/slideLayout[0-9]+\.xml\.rels$',
             r'^ppt/slideLayouts/slideLayout[0-9]+\.xml$',
-            r'^(?:word|ppt)/tableStyles\.xml$',
+            r'^(?:word|ppt|xl)/tableStyles\.xml$',
             r'^ppt/slides/_rels/slide[0-9]*\.xml\.rels$',
             r'^ppt/slides/slide[0-9]*\.xml$',
             # https://msdn.microsoft.com/en-us/library/dd908153(v=office.12).aspx
-            r'^(?:word|ppt)/stylesWithEffects\.xml$',
+            r'^(?:word|ppt|xl)/stylesWithEffects\.xml$',
             r'^ppt/presentation\.xml$',
             # TODO: check if p:bgRef can be randomized
             r'^ppt/slideMasters/slideMaster[0-9]+\.xml',
@@ -106,20 +111,20 @@ class MSOfficeParser(ZipParser):
             r'^customXml/',
             r'webSettings\.xml$',
             r'^docProps/custom\.xml$',
-            r'^(?:word|ppt)/printerSettings/',
-            r'^(?:word|ppt)/theme',
-            r'^(?:word|ppt)/people\.xml$',
-            r'^(?:word|ppt)/numbering\.xml$',
-            r'^(?:word|ppt)/tags/',
+            r'^(?:word|ppt|xl)/printerSettings/',
+            r'^(?:word|ppt|xl)/theme',
+            r'^(?:word|ppt|xl)/people\.xml$',
+            r'^(?:word|ppt|xl)/numbering\.xml$',
+            r'^(?:word|ppt|xl)/tags/',
             # View properties like view mode, last viewed slide etc
-            r'^(?:word|ppt)/viewProps\.xml$',
+            r'^(?:word|ppt|xl)/viewProps\.xml$',
             # Additional presentation-wide properties like printing properties,
             # presentation show properties etc.
-            r'^(?:word|ppt)/presProps\.xml$',
+            r'^(?:word|ppt|xl)/presProps\.xml$',
 
             # we have an allowlist in self.files_to_keep,
             # so we can trash everything else
-            r'^(?:word|ppt)/_rels/',
+            r'^(?:word|ppt|xl)/_rels/',
         }))
 
         if self.__fill_files_to_keep_via_content_types() is False:
@@ -142,7 +147,7 @@ class MSOfficeParser(ZipParser):
         except ET.ParseError:
             return False
         for c in tree:
-            if 'PartName' not in c.attrib or 'ContentType' not in c.attrib:
+            if 'PartName' not in c.attrib or 'ContentType' not in c.attrib:  # pragma: no cover
                 continue
             elif c.attrib['ContentType'] in self.content_types_to_keep:
                 fname = c.attrib['PartName'][1:]  # remove leading `/`
@@ -265,8 +270,8 @@ class MSOfficeParser(ZipParser):
             logging.error("Unable to parse %s: %s", full_path, e)
             return False
 
-        if len(namespace.items()) != 1:
-            return False  # there should be only one namespace for Types
+        if len(namespace.items()) != 1:  # pragma: no cover
+            logging.debug("Got several namespaces for Types: %s", namespace.items())
 
         removed_fnames = set()
         with zipfile.ZipFile(self.filename) as zin:
@@ -356,7 +361,7 @@ class MSOfficeParser(ZipParser):
         if full_path.endswith('/[Content_Types].xml'):
             # this file contains references to files that we might
             # remove, and MS Office doesn't like dangling references
-            if self.__remove_content_type_members(full_path) is False:
+            if self.__remove_content_type_members(full_path) is False:  # pragma: no cover
                 return False
         elif full_path.endswith('/word/document.xml'):
             # this file contains the revisions
